// ---------------------------------------------------------------------------
// zHUD.cs -- Version 1.3 -- December 31, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// customizable zoom brackets
//
// - automatically adjusts to new zoom.cs zoom levels (3.5x, 4x, etc.)
// - always on-screen (optional)
// - adjustable time on-screen (optional)
// - 4 sizes to choose from
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\zHUD.cs", "1.3", "Lorne Laliberte", "Dec 31, 2000");

include("writer\\event.cs");
include("writer\\save.cs");
include("writer\\schedule.cs");
include("writer\\whud.cs");
include("writer\\you_died.cs");
include("writer\\you_respawned.cs");
include("writer\\you_spawned.cs");
include("writer\\zoom.cs", novol);

// ---------------------------------------------------------------------------
// DEFAULT SETTINGS:
//
// Edit these if you're running this script for the first time
// All subsequent settings must be done in the config\wp_zHUD.cs file

    // Number of seconds you want the brackets to appear on-screen after you
    // zoom in or out.  Use 0 if you want the brackets to remain on screen
    // all the time when you're not zoomed in.
    $zHUD::showFor = "3";

    // Special code to determine which bracket bitmaps to use:
    // "" for the small ones (4x4 pixels)
    // "m" for the medium ones (6x6 pixels)
    // "b" for the big ones (8x8 pixels -- same as default Tribes brackets)
    // "o" for special medium ones with black edges(6x6 pixels)
    $zHUD::bitmapType = "m";

// ---------------------------------------------------------------------------

WriterPrefs::load("zHUD");


function zHUD::setup()
{
    $zHUD::width = 4;
    $zHUD::height = 4;

    if(!String::ICompare($zHUD::bitmapType, "m")) // ==
    {
        $zHUD::width = 6;
        $zHUD::height = 6;
    }
    else if(!String::ICompare($zHUD::bitmapType, "o")) // ==
    {
        $zHUD::width = 6;
        $zHUD::height = 6;
    }
    else if(!String::ICompare($zHUD::bitmapType, "b")) // ==
    {
        $zHUD::width = 8;
        $zHUD::height = 8;
    }

    // make sure user has a valid bitmap type set
    if($zHUD::bitmapType != "")
    {
        if(String::findSubStr("bmo", $zHUD::bitmapType) == -1)
            $zHUD::bitmapType = "";
    }

    $zHUD::ul::bitmap = "<b0,0:writer\\zHUD\\ul" @ $zHUD::bitmapType @ ".bmp>";
    $zHUD::ur::bitmap = "<b0,0:writer\\zHUD\\ur" @ $zHUD::bitmapType @ ".bmp>";
    $zHUD::lr::bitmap = "<b0,0:writer\\zHUD\\lr" @ $zHUD::bitmapType @ ".bmp>";
    $zHUD::ll::bitmap = "<b0,0:writer\\zHUD\\ll" @ $zHUD::bitmapType @ ".bmp>";

    %screenx = getScreensizeX() - 1;
    %screeny = getScreensizeY() - 1;

    %midx = floor(%screenx/2);
    %midy = floor(%screeny/2);

    for(%i = 0; %i < $zoom::levels; %i++)
    {
        %t = floor(((%screenx/$zoom::mag[%i])/2));
        $zHUD::l::x[$zoom::mag[%i]] = %midx - %t;
        $zHUD::r::x[$zoom::mag[%i]] = %midx + %t - ($zHUD::width/2) - (($zHUD::width/2) - 2);

        %t = floor(((%screeny/$zoom::mag[%i])/2));
        $zHUD::u::y[$zoom::mag[%i]] = %midy - %t;
        $zHUD::l::y[$zoom::mag[%i]] = %midy + %t - ($zHUD::height/2) - (($zHUD::height/2) - 2);
    }
}


function zHUD::onZoomChanged(%mag)
{
    schedule::cancel(zHUD_schedule);

    wHUD::make(zHUDul, $zHUD::l::x[%mag], $zHUD::u::y[%mag], 11, $zHUD::height, 1, wif($zoomed || %mag <= 1, 0, 1), $zHUD::ul::bitmap);
    wHUD::make(zHUDur, $zHUD::r::x[%mag], $zHUD::u::y[%mag], 11, $zHUD::height, 1, wif($zoomed || %mag <= 1, 0, 1), $zHUD::ur::bitmap);
    wHUD::make(zHUDlr, $zHUD::r::x[%mag], $zHUD::l::y[%mag], 11, $zHUD::height, 1, wif($zoomed || %mag <= 1, 0, 1), $zHUD::lr::bitmap);
    wHUD::make(zHUDll, $zHUD::l::x[%mag], $zHUD::l::y[%mag], 11, $zHUD::height, 1, wif($zoomed || %mag <= 1, 0, 1), $zHUD::ll::bitmap);

    if($zHUD::showFor)
        schedule::add("zHUD::hide();", $zHUD::showFor, zHUD_schedule);
    return;
}


function zHUD::show()
{
    wHUD::show(zHUDul);
    wHUD::show(zHUDur);
    wHUD::show(zHUDlr);
    wHUD::show(zHUDll);

    if($zHUD::showFor)
        schedule::add("zHUD::hide();", $zHUD::showFor, zHUD_schedule);

    return;
}


function zHUD::hide()
{
    wHUD::hide(zHUDul);
    wHUD::hide(zHUDur);
    wHUD::hide(zHUDlr);
    wHUD::hide(zHUDll);
    return;
}

function zHUD::onYouSpawned()
{
    zHUD::setup();
    zHUD::onZoomChanged($zoom::mag[$zoom::level]);
    return;
}


function zHUD::relocate()
{
    zHUD::setup();
    zHUD::onZoomChanged($zoom::mag[$zoom::level]);
    return;
}


function zHUD::save()
{
    AddExportText("    // Number of seconds you want the brackets to appear on-screen after you");
    AddExportText("    // zoom in or out.  Use 0 if you want the brackets to remain on screen");
    AddExportText("    // all the time (when you're not zoomed in).");
    ExportSetting("    $zHUD::showFor", 3);
    AddExportText("");
    AddExportText("    // Special code to determine which bracket bitmaps to use:");
    AddExportText("    // \"\" for the small ones (4x4 pixels)");
    AddExportText("    // \"m\" for the medium ones (6x6 pixels)");
    AddExportText("    // \"b\" for the big ones (8x8 pixels -- same as default Tribes brackets)");
    AddExportText("    // \"o\" for special small ones with black edges(4x4 pixels)");
    ExportSetting("    $zHUD::bitmapType", "m");
}

WriterPrefs::save("zHUD");

function zHUD::init()
{
    needs("writer\\zHUD.cs", "writer\\event.cs 2.7",
                             "writer\\save.cs 2.3",
                             "writer\\schedule.cs 1.3",
                             "writer\\wHUD.cs 1.2",
                             "writer\\you_died.cs 1.6",
                             "writer\\you_respawned.cs 1.2",
                             "writer\\you_spawned.cs 1.1",
                             "writer\\zoom.cs 4.2");

    // Reset zoom level upon joining a game
    Event::Attach(eventChangeMission, "zHUD::hide();");
    Event::Attach(eventScreenModeChanged, "zHUD::relocate();");
    Event::Attach(eventScreenSizeChanged, "zHUD::relocate();");
    Event::Attach(eventYouRespawned, "zHUD::show();");
    Event::Attach(eventYouSpawned, "zHUD::onYouSpawned();");
    Event::Attach(eventZoomChanged, zHUD::onZoomChanged);
    Event::Attach(eventZoomOn, "zHUD::hide();");

    if(!$zHUD::showFor)
        Event::Attach(eventZoomOff, "zHUD::show();");
}
Event::Attach(writerInit, "zHUD::init();");

if(!$UsingWriterLoader) zHUD::init();
